@@ -48,10 +48,14 @@ from . import forest_utils
 from . import utils
 
 from .utils.remeshing import remesh
+from .utils.gcode import gcode
+from .utils.fluid_analysis import reynolds, wss
+from .utils.gui import gui_helper
 
 from .tree import tree, forest, perfusion_territory
 from .implicit.implicit import surface
 from .implicit.tests.bumpy_sphere import bumpy_sphere
+from .implicit.tests.heart import *
 from .implicit.visualize.visualize import plot_volume
 #else:
 #    implicit = _ModuleProxy('implicit')
